pub struct ParsedDocument { /* private fields */ }Expand description
A fully parsed, self-contained document.
Owns the source text, tree-sitter tree, and pre-parsed expression cache.
Provides zero-copy wrapper access through root().
Implementations
Sourceimpl ParsedDocument
impl ParsedDocument
Sourcepub fn new(
owner: ParsedDocumentOwner,
dependent_builder: impl for<'_q> FnOnce(&'_q ParsedDocumentOwner) -> ParsedDocumentDependent<'_q>,
) -> Self
pub fn new( owner: ParsedDocumentOwner, dependent_builder: impl for<'_q> FnOnce(&'_q ParsedDocumentOwner) -> ParsedDocumentDependent<'_q>, ) -> Self
Constructs a new self-referential struct.
The provided owner will be moved into a heap allocated box. Followed by construction
of the dependent value, by calling dependent_builder with a shared reference to the
owner that remains valid for the lifetime of the constructed struct.
Sourcepub fn try_new<Err>(
owner: ParsedDocumentOwner,
dependent_builder: impl for<'_q> FnOnce(&'_q ParsedDocumentOwner) -> Result<ParsedDocumentDependent<'_q>, Err>,
) -> Result<Self, Err>
pub fn try_new<Err>( owner: ParsedDocumentOwner, dependent_builder: impl for<'_q> FnOnce(&'_q ParsedDocumentOwner) -> Result<ParsedDocumentDependent<'_q>, Err>, ) -> Result<Self, Err>
Constructs a new self-referential struct or returns an error.
Consumes owner on error.
Sourcepub fn try_new_or_recover<Err>(
owner: ParsedDocumentOwner,
dependent_builder: impl for<'_q> FnOnce(&'_q ParsedDocumentOwner) -> Result<ParsedDocumentDependent<'_q>, Err>,
) -> Result<Self, (ParsedDocumentOwner, Err)>
pub fn try_new_or_recover<Err>( owner: ParsedDocumentOwner, dependent_builder: impl for<'_q> FnOnce(&'_q ParsedDocumentOwner) -> Result<ParsedDocumentDependent<'_q>, Err>, ) -> Result<Self, (ParsedDocumentOwner, Err)>
Constructs a new self-referential struct or returns an error.
Returns owner and error as tuple on error.
Sourcepub fn borrow_owner<'_q>(&'_q self) -> &'_q ParsedDocumentOwner
pub fn borrow_owner<'_q>(&'_q self) -> &'_q ParsedDocumentOwner
Borrows owner.
Sourcepub fn with_dependent<'outer_fn, Ret>(
&'outer_fn self,
func: impl for<'_q> FnOnce(&'_q ParsedDocumentOwner, &'outer_fn ParsedDocumentDependent<'_q>) -> Ret,
) -> Ret
pub fn with_dependent<'outer_fn, Ret>( &'outer_fn self, func: impl for<'_q> FnOnce(&'_q ParsedDocumentOwner, &'outer_fn ParsedDocumentDependent<'_q>) -> Ret, ) -> Ret
Calls given closure func with a shared reference to dependent.
Sourcepub fn with_dependent_mut<'outer_fn, Ret>(
&'outer_fn mut self,
func: impl for<'_q> FnOnce(&'_q ParsedDocumentOwner, &'outer_fn mut ParsedDocumentDependent<'_q>) -> Ret,
) -> Ret
pub fn with_dependent_mut<'outer_fn, Ret>( &'outer_fn mut self, func: impl for<'_q> FnOnce(&'_q ParsedDocumentOwner, &'outer_fn mut ParsedDocumentDependent<'_q>) -> Ret, ) -> Ret
Calls given closure func with an unique reference to dependent.
Sourcepub fn borrow_dependent<'_q>(&'_q self) -> &'_q ParsedDocumentDependent<'_q>
pub fn borrow_dependent<'_q>(&'_q self) -> &'_q ParsedDocumentDependent<'_q>
Borrows dependent.
Sourcepub fn into_owner(self) -> ParsedDocumentOwner
pub fn into_owner(self) -> ParsedDocumentOwner
Consumes self and returns the the owner.
Sourceimpl ParsedDocument
impl ParsedDocument
Sourcepub fn parse(source: &str) -> Result<Self, CompileError>
pub fn parse(source: &str) -> Result<Self, CompileError>
Parse source into a fully self-contained document.
Sourcepub fn expressions(&self) -> &ExpressionCache
pub fn expressions(&self) -> &ExpressionCache
The pre-parsed expression cache.