pub fn parse_modern_root(source: &str) -> Result<Root, CompileError>Expand description
Parse a Svelte component directly into the modern AST root.
pub fn parse_modern_root(source: &str) -> Result<Root, CompileError>Parse a Svelte component directly into the modern AST root.